@@ -3,6 +3,9 @@
 #
 . /etc/init.d/rc.functions
 
+# $HOME is not yet set.
+HOME=/root
+
 # Sound configuration stuff. First check if sound=no and remoce all sound
 # Kernel modules.
 #
@@ -25,8 +28,10 @@ if grep -q "sound=" /proc/cmdline; then
 	noconf)
 		echo "Sound configuration is disable from cmdline...";;
 	*)
-		echo "Using sound kernel module $DRIVER..."
-		echo "snd-$DRIVER" > /var/lib/sound-card-driver;;
+		if [ -x /usr/sbin/soundconf ]; then
+			echo "Using sound kernel module $DRIVER..."
+			/usr/sbin/soundconf -M $DRIVER
+		fi;;
 	esac
 elif [ ! -f /var/lib/sound-card-driver ]; then
 	if [ -x /usr/sbin/soundconf ]; then
@@ -44,8 +49,11 @@ if [ -f /var/lib/sound-card-driver ]; then
 	status
 else
 	# Remove LXpanel volumealsa if no sound configuration.
-	if [ -f /usr/share/lxpanel/profile/default/config ]; then 
-		sed -i s/'volumealsa'/'space'/ /usr/share/lxpanel/profile/default/config
+	if [ -f /etc/lxpanel/default/config ]; then 
+		sed -i s/'volumealsa'/'space'/ /etc/lxpanel/default/config
+	fi
+	if [ -f /etc/lxpanel/openbox/config ]; then 
+		sed -i s/'volumealsa'/'space'/ /etc/lxpanel/openbox/config
 	fi
 fi
 
@@ -58,9 +66,9 @@ if [ ! -f /etc/X11/screen.conf -a -x /usr/bin/slim ]; then
 			sed -i s/'slim'/''/ /etc/rcS.conf
 			status
 		else
-			tazx
+			tazx `cat /etc/X11/wm.default`
 		fi
 	else
-		tazx
+		tazx `cat /etc/X11/wm.default`
 	fi
 fi
