@@ -27,11 +27,16 @@ if [ "$STATIC" = "yes" ] ; then
 	echo "Configuring static IP on $INTERFACE: $IP... "
 	/sbin/ifconfig $INTERFACE $IP netmask $NETMASK up
 	/sbin/route add default gateway $GATEWAY
-	echo "nameserver $DNS_SERVER" > /etc/resolv.conf
+	# Multi-DNS server in $DNS_SERVER.
+	/bin/mv /etc/resolv.conf /tmp/resolv.conf.$$
+	for NS in $DNS_SERVER
+	do
+		echo "nameserver $NS" >> /etc/resolv.conf
+	done
 fi
 
 # For wifi (experimental).
-if [ "$WIFI" = "yes" -o grep -q "wifi" /proc/cmdline ] ; then
+if [ "$WIFI" = "yes" ] || grep -q "wifi" /proc/cmdline; then
 	iwconfig $WIFI_INTERFACE essid $ESSID
 	echo "Starting udhcpc client on: $INTERFACE... "
 	/sbin/udhcpc -b -i $WIFI_INTERFACE \
